"""
Setup script for types-aiobotocore.
"""
from pathlib import Path

from setuptools import setup

LONG_DESCRIPTION = (Path(__file__).parent / "README.md").read_text()


setup(
    name="types-aiobotocore",
    version="2.6.0",
    packages=["aiobotocore-stubs"],
    url="https://github.com/youtype/mypy_boto3_builder",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Type annotations for aiobotocore 2.6.0 generated with mypy-boto3-builder 7.17.2",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Stubs Only",
    ],
    keywords=(
        "aiobotocore type-annotations aiobotocore-stubs botocore-stubs mypy typeshed autocomplete"
    ),
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    package_data={"aiobotocore-stubs": ["py.typed", "*.pyi", "*/*.pyi"]},
    python_requires=">=3.7",
    project_urls={
        "Documentation": "https://youtype.github.io/types_aiobotocore_docs/",
        "Source": "https://github.com/youtype/mypy_boto3_builder",
        "Tracker": "https://github.com/youtype/mypy_boto3_builder/issues",
    },
    install_requires=[
        "botocore-stubs",
        'typing-extensions>=4.1.0; python_version<"3.9"',
    ],
    extras_require={
        "all": [
            "types-aiobotocore-accessanalyzer>=2.6.0, <2.7.0",
            "types-aiobotocore-account>=2.6.0, <2.7.0",
            "types-aiobotocore-acm>=2.6.0, <2.7.0",
            "types-aiobotocore-acm-pca>=2.6.0, <2.7.0",
            "types-aiobotocore-alexaforbusiness>=2.6.0, <2.7.0",
            "types-aiobotocore-amp>=2.6.0, <2.7.0",
            "types-aiobotocore-amplify>=2.6.0, <2.7.0",
            "types-aiobotocore-amplifybackend>=2.6.0, <2.7.0",
            "types-aiobotocore-amplifyuibuilder>=2.6.0, <2.7.0",
            "types-aiobotocore-apigateway>=2.6.0, <2.7.0",
            "types-aiobotocore-apigatewaymanagementapi>=2.6.0, <2.7.0",
            "types-aiobotocore-apigatewayv2>=2.6.0, <2.7.0",
            "types-aiobotocore-appconfig>=2.6.0, <2.7.0",
            "types-aiobotocore-appconfigdata>=2.6.0, <2.7.0",
            "types-aiobotocore-appfabric>=2.6.0, <2.7.0",
            "types-aiobotocore-appflow>=2.6.0, <2.7.0",
            "types-aiobotocore-appintegrations>=2.6.0, <2.7.0",
            "types-aiobotocore-application-autoscaling>=2.6.0, <2.7.0",
            "types-aiobotocore-application-insights>=2.6.0, <2.7.0",
            "types-aiobotocore-applicationcostprofiler>=2.6.0, <2.7.0",
            "types-aiobotocore-appmesh>=2.6.0, <2.7.0",
            "types-aiobotocore-apprunner>=2.6.0, <2.7.0",
            "types-aiobotocore-appstream>=2.6.0, <2.7.0",
            "types-aiobotocore-appsync>=2.6.0, <2.7.0",
            "types-aiobotocore-arc-zonal-shift>=2.6.0, <2.7.0",
            "types-aiobotocore-athena>=2.6.0, <2.7.0",
            "types-aiobotocore-auditmanager>=2.6.0, <2.7.0",
            "types-aiobotocore-autoscaling>=2.6.0, <2.7.0",
            "types-aiobotocore-autoscaling-plans>=2.6.0, <2.7.0",
            "types-aiobotocore-backup>=2.6.0, <2.7.0",
            "types-aiobotocore-backup-gateway>=2.6.0, <2.7.0",
            "types-aiobotocore-backupstorage>=2.6.0, <2.7.0",
            "types-aiobotocore-batch>=2.6.0, <2.7.0",
            "types-aiobotocore-billingconductor>=2.6.0, <2.7.0",
            "types-aiobotocore-braket>=2.6.0, <2.7.0",
            "types-aiobotocore-budgets>=2.6.0, <2.7.0",
            "types-aiobotocore-ce>=2.6.0, <2.7.0",
            "types-aiobotocore-chime>=2.6.0, <2.7.0",
            "types-aiobotocore-chime-sdk-identity>=2.6.0, <2.7.0",
            "types-aiobotocore-chime-sdk-media-pipelines>=2.6.0, <2.7.0",
            "types-aiobotocore-chime-sdk-meetings>=2.6.0, <2.7.0",
            "types-aiobotocore-chime-sdk-messaging>=2.6.0, <2.7.0",
            "types-aiobotocore-chime-sdk-voice>=2.6.0, <2.7.0",
            "types-aiobotocore-cleanrooms>=2.6.0, <2.7.0",
            "types-aiobotocore-cloud9>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudcontrol>=2.6.0, <2.7.0",
            "types-aiobotocore-clouddirectory>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudformation>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudfront>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudhsm>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudhsmv2>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudsearch>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudsearchdomain>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudtrail>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudtrail-data>=2.6.0, <2.7.0",
            "types-aiobotocore-cloudwatch>=2.6.0, <2.7.0",
            "types-aiobotocore-codeartifact>=2.6.0, <2.7.0",
            "types-aiobotocore-codebuild>=2.6.0, <2.7.0",
            "types-aiobotocore-codecatalyst>=2.6.0, <2.7.0",
            "types-aiobotocore-codecommit>=2.6.0, <2.7.0",
            "types-aiobotocore-codedeploy>=2.6.0, <2.7.0",
            "types-aiobotocore-codeguru-reviewer>=2.6.0, <2.7.0",
            "types-aiobotocore-codeguru-security>=2.6.0, <2.7.0",
            "types-aiobotocore-codeguruprofiler>=2.6.0, <2.7.0",
            "types-aiobotocore-codepipeline>=2.6.0, <2.7.0",
            "types-aiobotocore-codestar>=2.6.0, <2.7.0",
            "types-aiobotocore-codestar-connections>=2.6.0, <2.7.0",
            "types-aiobotocore-codestar-notifications>=2.6.0, <2.7.0",
            "types-aiobotocore-cognito-identity>=2.6.0, <2.7.0",
            "types-aiobotocore-cognito-idp>=2.6.0, <2.7.0",
            "types-aiobotocore-cognito-sync>=2.6.0, <2.7.0",
            "types-aiobotocore-comprehend>=2.6.0, <2.7.0",
            "types-aiobotocore-comprehendmedical>=2.6.0, <2.7.0",
            "types-aiobotocore-compute-optimizer>=2.6.0, <2.7.0",
            "types-aiobotocore-config>=2.6.0, <2.7.0",
            "types-aiobotocore-connect>=2.6.0, <2.7.0",
            "types-aiobotocore-connect-contact-lens>=2.6.0, <2.7.0",
            "types-aiobotocore-connectcampaigns>=2.6.0, <2.7.0",
            "types-aiobotocore-connectcases>=2.6.0, <2.7.0",
            "types-aiobotocore-connectparticipant>=2.6.0, <2.7.0",
            "types-aiobotocore-controltower>=2.6.0, <2.7.0",
            "types-aiobotocore-cur>=2.6.0, <2.7.0",
            "types-aiobotocore-customer-profiles>=2.6.0, <2.7.0",
            "types-aiobotocore-databrew>=2.6.0, <2.7.0",
            "types-aiobotocore-dataexchange>=2.6.0, <2.7.0",
            "types-aiobotocore-datapipeline>=2.6.0, <2.7.0",
            "types-aiobotocore-datasync>=2.6.0, <2.7.0",
            "types-aiobotocore-dax>=2.6.0, <2.7.0",
            "types-aiobotocore-detective>=2.6.0, <2.7.0",
            "types-aiobotocore-devicefarm>=2.6.0, <2.7.0",
            "types-aiobotocore-devops-guru>=2.6.0, <2.7.0",
            "types-aiobotocore-directconnect>=2.6.0, <2.7.0",
            "types-aiobotocore-discovery>=2.6.0, <2.7.0",
            "types-aiobotocore-dlm>=2.6.0, <2.7.0",
            "types-aiobotocore-dms>=2.6.0, <2.7.0",
            "types-aiobotocore-docdb>=2.6.0, <2.7.0",
            "types-aiobotocore-docdb-elastic>=2.6.0, <2.7.0",
            "types-aiobotocore-drs>=2.6.0, <2.7.0",
            "types-aiobotocore-ds>=2.6.0, <2.7.0",
            "types-aiobotocore-dynamodb>=2.6.0, <2.7.0",
            "types-aiobotocore-dynamodbstreams>=2.6.0, <2.7.0",
            "types-aiobotocore-ebs>=2.6.0, <2.7.0",
            "types-aiobotocore-ec2>=2.6.0, <2.7.0",
            "types-aiobotocore-ec2-instance-connect>=2.6.0, <2.7.0",
            "types-aiobotocore-ecr>=2.6.0, <2.7.0",
            "types-aiobotocore-ecr-public>=2.6.0, <2.7.0",
            "types-aiobotocore-ecs>=2.6.0, <2.7.0",
            "types-aiobotocore-efs>=2.6.0, <2.7.0",
            "types-aiobotocore-eks>=2.6.0, <2.7.0",
            "types-aiobotocore-elastic-inference>=2.6.0, <2.7.0",
            "types-aiobotocore-elasticache>=2.6.0, <2.7.0",
            "types-aiobotocore-elasticbeanstalk>=2.6.0, <2.7.0",
            "types-aiobotocore-elastictranscoder>=2.6.0, <2.7.0",
            "types-aiobotocore-elb>=2.6.0, <2.7.0",
            "types-aiobotocore-elbv2>=2.6.0, <2.7.0",
            "types-aiobotocore-emr>=2.6.0, <2.7.0",
            "types-aiobotocore-emr-containers>=2.6.0, <2.7.0",
            "types-aiobotocore-emr-serverless>=2.6.0, <2.7.0",
            "types-aiobotocore-entityresolution>=2.6.0, <2.7.0",
            "types-aiobotocore-es>=2.6.0, <2.7.0",
            "types-aiobotocore-events>=2.6.0, <2.7.0",
            "types-aiobotocore-evidently>=2.6.0, <2.7.0",
            "types-aiobotocore-finspace>=2.6.0, <2.7.0",
            "types-aiobotocore-finspace-data>=2.6.0, <2.7.0",
            "types-aiobotocore-firehose>=2.6.0, <2.7.0",
            "types-aiobotocore-fis>=2.6.0, <2.7.0",
            "types-aiobotocore-fms>=2.6.0, <2.7.0",
            "types-aiobotocore-forecast>=2.6.0, <2.7.0",
            "types-aiobotocore-forecastquery>=2.6.0, <2.7.0",
            "types-aiobotocore-frauddetector>=2.6.0, <2.7.0",
            "types-aiobotocore-fsx>=2.6.0, <2.7.0",
            "types-aiobotocore-gamelift>=2.6.0, <2.7.0",
            "types-aiobotocore-gamesparks>=2.6.0, <2.7.0",
            "types-aiobotocore-glacier>=2.6.0, <2.7.0",
            "types-aiobotocore-globalaccelerator>=2.6.0, <2.7.0",
            "types-aiobotocore-glue>=2.6.0, <2.7.0",
            "types-aiobotocore-grafana>=2.6.0, <2.7.0",
            "types-aiobotocore-greengrass>=2.6.0, <2.7.0",
            "types-aiobotocore-greengrassv2>=2.6.0, <2.7.0",
            "types-aiobotocore-groundstation>=2.6.0, <2.7.0",
            "types-aiobotocore-guardduty>=2.6.0, <2.7.0",
            "types-aiobotocore-health>=2.6.0, <2.7.0",
            "types-aiobotocore-healthlake>=2.6.0, <2.7.0",
            "types-aiobotocore-honeycode>=2.6.0, <2.7.0",
            "types-aiobotocore-iam>=2.6.0, <2.7.0",
            "types-aiobotocore-identitystore>=2.6.0, <2.7.0",
            "types-aiobotocore-imagebuilder>=2.6.0, <2.7.0",
            "types-aiobotocore-importexport>=2.6.0, <2.7.0",
            "types-aiobotocore-inspector>=2.6.0, <2.7.0",
            "types-aiobotocore-inspector2>=2.6.0, <2.7.0",
            "types-aiobotocore-internetmonitor>=2.6.0, <2.7.0",
            "types-aiobotocore-iot>=2.6.0, <2.7.0",
            "types-aiobotocore-iot-data>=2.6.0, <2.7.0",
            "types-aiobotocore-iot-jobs-data>=2.6.0, <2.7.0",
            "types-aiobotocore-iot-roborunner>=2.6.0, <2.7.0",
            "types-aiobotocore-iot1click-devices>=2.6.0, <2.7.0",
            "types-aiobotocore-iot1click-projects>=2.6.0, <2.7.0",
            "types-aiobotocore-iotanalytics>=2.6.0, <2.7.0",
            "types-aiobotocore-iotdeviceadvisor>=2.6.0, <2.7.0",
            "types-aiobotocore-iotevents>=2.6.0, <2.7.0",
            "types-aiobotocore-iotevents-data>=2.6.0, <2.7.0",
            "types-aiobotocore-iotfleethub>=2.6.0, <2.7.0",
            "types-aiobotocore-iotfleetwise>=2.6.0, <2.7.0",
            "types-aiobotocore-iotsecuretunneling>=2.6.0, <2.7.0",
            "types-aiobotocore-iotsitewise>=2.6.0, <2.7.0",
            "types-aiobotocore-iotthingsgraph>=2.6.0, <2.7.0",
            "types-aiobotocore-iottwinmaker>=2.6.0, <2.7.0",
            "types-aiobotocore-iotwireless>=2.6.0, <2.7.0",
            "types-aiobotocore-ivs>=2.6.0, <2.7.0",
            "types-aiobotocore-ivs-realtime>=2.6.0, <2.7.0",
            "types-aiobotocore-ivschat>=2.6.0, <2.7.0",
            "types-aiobotocore-kafka>=2.6.0, <2.7.0",
            "types-aiobotocore-kafkaconnect>=2.6.0, <2.7.0",
            "types-aiobotocore-kendra>=2.6.0, <2.7.0",
            "types-aiobotocore-kendra-ranking>=2.6.0, <2.7.0",
            "types-aiobotocore-keyspaces>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesis>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesis-video-archived-media>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesis-video-media>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesis-video-signaling>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesis-video-webrtc-storage>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesisanalytics>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesisanalyticsv2>=2.6.0, <2.7.0",
            "types-aiobotocore-kinesisvideo>=2.6.0, <2.7.0",
            "types-aiobotocore-kms>=2.6.0, <2.7.0",
            "types-aiobotocore-lakeformation>=2.6.0, <2.7.0",
            "types-aiobotocore-lambda>=2.6.0, <2.7.0",
            "types-aiobotocore-lex-models>=2.6.0, <2.7.0",
            "types-aiobotocore-lex-runtime>=2.6.0, <2.7.0",
            "types-aiobotocore-lexv2-models>=2.6.0, <2.7.0",
            "types-aiobotocore-lexv2-runtime>=2.6.0, <2.7.0",
            "types-aiobotocore-license-manager>=2.6.0, <2.7.0",
            "types-aiobotocore-license-manager-linux-subscriptions>=2.6.0, <2.7.0",
            "types-aiobotocore-license-manager-user-subscriptions>=2.6.0, <2.7.0",
            "types-aiobotocore-lightsail>=2.6.0, <2.7.0",
            "types-aiobotocore-location>=2.6.0, <2.7.0",
            "types-aiobotocore-logs>=2.6.0, <2.7.0",
            "types-aiobotocore-lookoutequipment>=2.6.0, <2.7.0",
            "types-aiobotocore-lookoutmetrics>=2.6.0, <2.7.0",
            "types-aiobotocore-lookoutvision>=2.6.0, <2.7.0",
            "types-aiobotocore-m2>=2.6.0, <2.7.0",
            "types-aiobotocore-machinelearning>=2.6.0, <2.7.0",
            "types-aiobotocore-macie>=2.6.0, <2.7.0",
            "types-aiobotocore-macie2>=2.6.0, <2.7.0",
            "types-aiobotocore-managedblockchain>=2.6.0, <2.7.0",
            "types-aiobotocore-managedblockchain-query>=2.6.0, <2.7.0",
            "types-aiobotocore-marketplace-catalog>=2.6.0, <2.7.0",
            "types-aiobotocore-marketplace-entitlement>=2.6.0, <2.7.0",
            "types-aiobotocore-marketplacecommerceanalytics>=2.6.0, <2.7.0",
            "types-aiobotocore-mediaconnect>=2.6.0, <2.7.0",
            "types-aiobotocore-mediaconvert>=2.6.0, <2.7.0",
            "types-aiobotocore-medialive>=2.6.0, <2.7.0",
            "types-aiobotocore-mediapackage>=2.6.0, <2.7.0",
            "types-aiobotocore-mediapackage-vod>=2.6.0, <2.7.0",
            "types-aiobotocore-mediapackagev2>=2.6.0, <2.7.0",
            "types-aiobotocore-mediastore>=2.6.0, <2.7.0",
            "types-aiobotocore-mediastore-data>=2.6.0, <2.7.0",
            "types-aiobotocore-mediatailor>=2.6.0, <2.7.0",
            "types-aiobotocore-medical-imaging>=2.6.0, <2.7.0",
            "types-aiobotocore-memorydb>=2.6.0, <2.7.0",
            "types-aiobotocore-meteringmarketplace>=2.6.0, <2.7.0",
            "types-aiobotocore-mgh>=2.6.0, <2.7.0",
            "types-aiobotocore-mgn>=2.6.0, <2.7.0",
            "types-aiobotocore-migration-hub-refactor-spaces>=2.6.0, <2.7.0",
            "types-aiobotocore-migrationhub-config>=2.6.0, <2.7.0",
            "types-aiobotocore-migrationhuborchestrator>=2.6.0, <2.7.0",
            "types-aiobotocore-migrationhubstrategy>=2.6.0, <2.7.0",
            "types-aiobotocore-mobile>=2.6.0, <2.7.0",
            "types-aiobotocore-mq>=2.6.0, <2.7.0",
            "types-aiobotocore-mturk>=2.6.0, <2.7.0",
            "types-aiobotocore-mwaa>=2.6.0, <2.7.0",
            "types-aiobotocore-neptune>=2.6.0, <2.7.0",
            "types-aiobotocore-network-firewall>=2.6.0, <2.7.0",
            "types-aiobotocore-networkmanager>=2.6.0, <2.7.0",
            "types-aiobotocore-nimble>=2.6.0, <2.7.0",
            "types-aiobotocore-oam>=2.6.0, <2.7.0",
            "types-aiobotocore-omics>=2.6.0, <2.7.0",
            "types-aiobotocore-opensearch>=2.6.0, <2.7.0",
            "types-aiobotocore-opensearchserverless>=2.6.0, <2.7.0",
            "types-aiobotocore-opsworks>=2.6.0, <2.7.0",
            "types-aiobotocore-opsworkscm>=2.6.0, <2.7.0",
            "types-aiobotocore-organizations>=2.6.0, <2.7.0",
            "types-aiobotocore-osis>=2.6.0, <2.7.0",
            "types-aiobotocore-outposts>=2.6.0, <2.7.0",
            "types-aiobotocore-panorama>=2.6.0, <2.7.0",
            "types-aiobotocore-payment-cryptography>=2.6.0, <2.7.0",
            "types-aiobotocore-payment-cryptography-data>=2.6.0, <2.7.0",
            "types-aiobotocore-personalize>=2.6.0, <2.7.0",
            "types-aiobotocore-personalize-events>=2.6.0, <2.7.0",
            "types-aiobotocore-personalize-runtime>=2.6.0, <2.7.0",
            "types-aiobotocore-pi>=2.6.0, <2.7.0",
            "types-aiobotocore-pinpoint>=2.6.0, <2.7.0",
            "types-aiobotocore-pinpoint-email>=2.6.0, <2.7.0",
            "types-aiobotocore-pinpoint-sms-voice>=2.6.0, <2.7.0",
            "types-aiobotocore-pinpoint-sms-voice-v2>=2.6.0, <2.7.0",
            "types-aiobotocore-pipes>=2.6.0, <2.7.0",
            "types-aiobotocore-polly>=2.6.0, <2.7.0",
            "types-aiobotocore-pricing>=2.6.0, <2.7.0",
            "types-aiobotocore-privatenetworks>=2.6.0, <2.7.0",
            "types-aiobotocore-proton>=2.6.0, <2.7.0",
            "types-aiobotocore-qldb>=2.6.0, <2.7.0",
            "types-aiobotocore-qldb-session>=2.6.0, <2.7.0",
            "types-aiobotocore-quicksight>=2.6.0, <2.7.0",
            "types-aiobotocore-ram>=2.6.0, <2.7.0",
            "types-aiobotocore-rbin>=2.6.0, <2.7.0",
            "types-aiobotocore-rds>=2.6.0, <2.7.0",
            "types-aiobotocore-rds-data>=2.6.0, <2.7.0",
            "types-aiobotocore-redshift>=2.6.0, <2.7.0",
            "types-aiobotocore-redshift-data>=2.6.0, <2.7.0",
            "types-aiobotocore-redshift-serverless>=2.6.0, <2.7.0",
            "types-aiobotocore-rekognition>=2.6.0, <2.7.0",
            "types-aiobotocore-resiliencehub>=2.6.0, <2.7.0",
            "types-aiobotocore-resource-explorer-2>=2.6.0, <2.7.0",
            "types-aiobotocore-resource-groups>=2.6.0, <2.7.0",
            "types-aiobotocore-resourcegroupstaggingapi>=2.6.0, <2.7.0",
            "types-aiobotocore-robomaker>=2.6.0, <2.7.0",
            "types-aiobotocore-rolesanywhere>=2.6.0, <2.7.0",
            "types-aiobotocore-route53>=2.6.0, <2.7.0",
            "types-aiobotocore-route53-recovery-cluster>=2.6.0, <2.7.0",
            "types-aiobotocore-route53-recovery-control-config>=2.6.0, <2.7.0",
            "types-aiobotocore-route53-recovery-readiness>=2.6.0, <2.7.0",
            "types-aiobotocore-route53domains>=2.6.0, <2.7.0",
            "types-aiobotocore-route53resolver>=2.6.0, <2.7.0",
            "types-aiobotocore-rum>=2.6.0, <2.7.0",
            "types-aiobotocore-s3>=2.6.0, <2.7.0",
            "types-aiobotocore-s3control>=2.6.0, <2.7.0",
            "types-aiobotocore-s3outposts>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker-a2i-runtime>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker-edge>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker-featurestore-runtime>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker-geospatial>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker-metrics>=2.6.0, <2.7.0",
            "types-aiobotocore-sagemaker-runtime>=2.6.0, <2.7.0",
            "types-aiobotocore-savingsplans>=2.6.0, <2.7.0",
            "types-aiobotocore-scheduler>=2.6.0, <2.7.0",
            "types-aiobotocore-schemas>=2.6.0, <2.7.0",
            "types-aiobotocore-sdb>=2.6.0, <2.7.0",
            "types-aiobotocore-secretsmanager>=2.6.0, <2.7.0",
            "types-aiobotocore-securityhub>=2.6.0, <2.7.0",
            "types-aiobotocore-securitylake>=2.6.0, <2.7.0",
            "types-aiobotocore-serverlessrepo>=2.6.0, <2.7.0",
            "types-aiobotocore-service-quotas>=2.6.0, <2.7.0",
            "types-aiobotocore-servicecatalog>=2.6.0, <2.7.0",
            "types-aiobotocore-servicecatalog-appregistry>=2.6.0, <2.7.0",
            "types-aiobotocore-servicediscovery>=2.6.0, <2.7.0",
            "types-aiobotocore-ses>=2.6.0, <2.7.0",
            "types-aiobotocore-sesv2>=2.6.0, <2.7.0",
            "types-aiobotocore-shield>=2.6.0, <2.7.0",
            "types-aiobotocore-signer>=2.6.0, <2.7.0",
            "types-aiobotocore-simspaceweaver>=2.6.0, <2.7.0",
            "types-aiobotocore-sms>=2.6.0, <2.7.0",
            "types-aiobotocore-sms-voice>=2.6.0, <2.7.0",
            "types-aiobotocore-snow-device-management>=2.6.0, <2.7.0",
            "types-aiobotocore-snowball>=2.6.0, <2.7.0",
            "types-aiobotocore-sns>=2.6.0, <2.7.0",
            "types-aiobotocore-sqs>=2.6.0, <2.7.0",
            "types-aiobotocore-ssm>=2.6.0, <2.7.0",
            "types-aiobotocore-ssm-contacts>=2.6.0, <2.7.0",
            "types-aiobotocore-ssm-incidents>=2.6.0, <2.7.0",
            "types-aiobotocore-ssm-sap>=2.6.0, <2.7.0",
            "types-aiobotocore-sso>=2.6.0, <2.7.0",
            "types-aiobotocore-sso-admin>=2.6.0, <2.7.0",
            "types-aiobotocore-sso-oidc>=2.6.0, <2.7.0",
            "types-aiobotocore-stepfunctions>=2.6.0, <2.7.0",
            "types-aiobotocore-storagegateway>=2.6.0, <2.7.0",
            "types-aiobotocore-sts>=2.6.0, <2.7.0",
            "types-aiobotocore-support>=2.6.0, <2.7.0",
            "types-aiobotocore-support-app>=2.6.0, <2.7.0",
            "types-aiobotocore-swf>=2.6.0, <2.7.0",
            "types-aiobotocore-synthetics>=2.6.0, <2.7.0",
            "types-aiobotocore-textract>=2.6.0, <2.7.0",
            "types-aiobotocore-timestream-query>=2.6.0, <2.7.0",
            "types-aiobotocore-timestream-write>=2.6.0, <2.7.0",
            "types-aiobotocore-tnb>=2.6.0, <2.7.0",
            "types-aiobotocore-transcribe>=2.6.0, <2.7.0",
            "types-aiobotocore-transfer>=2.6.0, <2.7.0",
            "types-aiobotocore-translate>=2.6.0, <2.7.0",
            "types-aiobotocore-verifiedpermissions>=2.6.0, <2.7.0",
            "types-aiobotocore-voice-id>=2.6.0, <2.7.0",
            "types-aiobotocore-vpc-lattice>=2.6.0, <2.7.0",
            "types-aiobotocore-waf>=2.6.0, <2.7.0",
            "types-aiobotocore-waf-regional>=2.6.0, <2.7.0",
            "types-aiobotocore-wafv2>=2.6.0, <2.7.0",
            "types-aiobotocore-wellarchitected>=2.6.0, <2.7.0",
            "types-aiobotocore-wisdom>=2.6.0, <2.7.0",
            "types-aiobotocore-workdocs>=2.6.0, <2.7.0",
            "types-aiobotocore-worklink>=2.6.0, <2.7.0",
            "types-aiobotocore-workmail>=2.6.0, <2.7.0",
            "types-aiobotocore-workmailmessageflow>=2.6.0, <2.7.0",
            "types-aiobotocore-workspaces>=2.6.0, <2.7.0",
            "types-aiobotocore-workspaces-web>=2.6.0, <2.7.0",
            "types-aiobotocore-xray>=2.6.0, <2.7.0",
        ],
        "essential": [
            "types-aiobotocore-cloudformation>=2.6.0, <2.7.0",
            "types-aiobotocore-dynamodb>=2.6.0, <2.7.0",
            "types-aiobotocore-ec2>=2.6.0, <2.7.0",
            "types-aiobotocore-lambda>=2.6.0, <2.7.0",
            "types-aiobotocore-rds>=2.6.0, <2.7.0",
            "types-aiobotocore-s3>=2.6.0, <2.7.0",
            "types-aiobotocore-sqs>=2.6.0, <2.7.0",
        ],
        "aiobotocore": ["aiobotocore==2.6.0", "botocore==1.31.17"],
        "accessanalyzer": ["types-aiobotocore-accessanalyzer>=2.6.0, <2.7.0"],
        "account": ["types-aiobotocore-account>=2.6.0, <2.7.0"],
        "acm": ["types-aiobotocore-acm>=2.6.0, <2.7.0"],
        "acm-pca": ["types-aiobotocore-acm-pca>=2.6.0, <2.7.0"],
        "alexaforbusiness": ["types-aiobotocore-alexaforbusiness>=2.6.0, <2.7.0"],
        "amp": ["types-aiobotocore-amp>=2.6.0, <2.7.0"],
        "amplify": ["types-aiobotocore-amplify>=2.6.0, <2.7.0"],
        "amplifybackend": ["types-aiobotocore-amplifybackend>=2.6.0, <2.7.0"],
        "amplifyuibuilder": ["types-aiobotocore-amplifyuibuilder>=2.6.0, <2.7.0"],
        "apigateway": ["types-aiobotocore-apigateway>=2.6.0, <2.7.0"],
        "apigatewaymanagementapi": ["types-aiobotocore-apigatewaymanagementapi>=2.6.0, <2.7.0"],
        "apigatewayv2": ["types-aiobotocore-apigatewayv2>=2.6.0, <2.7.0"],
        "appconfig": ["types-aiobotocore-appconfig>=2.6.0, <2.7.0"],
        "appconfigdata": ["types-aiobotocore-appconfigdata>=2.6.0, <2.7.0"],
        "appfabric": ["types-aiobotocore-appfabric>=2.6.0, <2.7.0"],
        "appflow": ["types-aiobotocore-appflow>=2.6.0, <2.7.0"],
        "appintegrations": ["types-aiobotocore-appintegrations>=2.6.0, <2.7.0"],
        "application-autoscaling": ["types-aiobotocore-application-autoscaling>=2.6.0, <2.7.0"],
        "application-insights": ["types-aiobotocore-application-insights>=2.6.0, <2.7.0"],
        "applicationcostprofiler": ["types-aiobotocore-applicationcostprofiler>=2.6.0, <2.7.0"],
        "appmesh": ["types-aiobotocore-appmesh>=2.6.0, <2.7.0"],
        "apprunner": ["types-aiobotocore-apprunner>=2.6.0, <2.7.0"],
        "appstream": ["types-aiobotocore-appstream>=2.6.0, <2.7.0"],
        "appsync": ["types-aiobotocore-appsync>=2.6.0, <2.7.0"],
        "arc-zonal-shift": ["types-aiobotocore-arc-zonal-shift>=2.6.0, <2.7.0"],
        "athena": ["types-aiobotocore-athena>=2.6.0, <2.7.0"],
        "auditmanager": ["types-aiobotocore-auditmanager>=2.6.0, <2.7.0"],
        "autoscaling": ["types-aiobotocore-autoscaling>=2.6.0, <2.7.0"],
        "autoscaling-plans": ["types-aiobotocore-autoscaling-plans>=2.6.0, <2.7.0"],
        "backup": ["types-aiobotocore-backup>=2.6.0, <2.7.0"],
        "backup-gateway": ["types-aiobotocore-backup-gateway>=2.6.0, <2.7.0"],
        "backupstorage": ["types-aiobotocore-backupstorage>=2.6.0, <2.7.0"],
        "batch": ["types-aiobotocore-batch>=2.6.0, <2.7.0"],
        "billingconductor": ["types-aiobotocore-billingconductor>=2.6.0, <2.7.0"],
        "braket": ["types-aiobotocore-braket>=2.6.0, <2.7.0"],
        "budgets": ["types-aiobotocore-budgets>=2.6.0, <2.7.0"],
        "ce": ["types-aiobotocore-ce>=2.6.0, <2.7.0"],
        "chime": ["types-aiobotocore-chime>=2.6.0, <2.7.0"],
        "chime-sdk-identity": ["types-aiobotocore-chime-sdk-identity>=2.6.0, <2.7.0"],
        "chime-sdk-media-pipelines": ["types-aiobotocore-chime-sdk-media-pipelines>=2.6.0, <2.7.0"],
        "chime-sdk-meetings": ["types-aiobotocore-chime-sdk-meetings>=2.6.0, <2.7.0"],
        "chime-sdk-messaging": ["types-aiobotocore-chime-sdk-messaging>=2.6.0, <2.7.0"],
        "chime-sdk-voice": ["types-aiobotocore-chime-sdk-voice>=2.6.0, <2.7.0"],
        "cleanrooms": ["types-aiobotocore-cleanrooms>=2.6.0, <2.7.0"],
        "cloud9": ["types-aiobotocore-cloud9>=2.6.0, <2.7.0"],
        "cloudcontrol": ["types-aiobotocore-cloudcontrol>=2.6.0, <2.7.0"],
        "clouddirectory": ["types-aiobotocore-clouddirectory>=2.6.0, <2.7.0"],
        "cloudformation": ["types-aiobotocore-cloudformation>=2.6.0, <2.7.0"],
        "cloudfront": ["types-aiobotocore-cloudfront>=2.6.0, <2.7.0"],
        "cloudhsm": ["types-aiobotocore-cloudhsm>=2.6.0, <2.7.0"],
        "cloudhsmv2": ["types-aiobotocore-cloudhsmv2>=2.6.0, <2.7.0"],
        "cloudsearch": ["types-aiobotocore-cloudsearch>=2.6.0, <2.7.0"],
        "cloudsearchdomain": ["types-aiobotocore-cloudsearchdomain>=2.6.0, <2.7.0"],
        "cloudtrail": ["types-aiobotocore-cloudtrail>=2.6.0, <2.7.0"],
        "cloudtrail-data": ["types-aiobotocore-cloudtrail-data>=2.6.0, <2.7.0"],
        "cloudwatch": ["types-aiobotocore-cloudwatch>=2.6.0, <2.7.0"],
        "codeartifact": ["types-aiobotocore-codeartifact>=2.6.0, <2.7.0"],
        "codebuild": ["types-aiobotocore-codebuild>=2.6.0, <2.7.0"],
        "codecatalyst": ["types-aiobotocore-codecatalyst>=2.6.0, <2.7.0"],
        "codecommit": ["types-aiobotocore-codecommit>=2.6.0, <2.7.0"],
        "codedeploy": ["types-aiobotocore-codedeploy>=2.6.0, <2.7.0"],
        "codeguru-reviewer": ["types-aiobotocore-codeguru-reviewer>=2.6.0, <2.7.0"],
        "codeguru-security": ["types-aiobotocore-codeguru-security>=2.6.0, <2.7.0"],
        "codeguruprofiler": ["types-aiobotocore-codeguruprofiler>=2.6.0, <2.7.0"],
        "codepipeline": ["types-aiobotocore-codepipeline>=2.6.0, <2.7.0"],
        "codestar": ["types-aiobotocore-codestar>=2.6.0, <2.7.0"],
        "codestar-connections": ["types-aiobotocore-codestar-connections>=2.6.0, <2.7.0"],
        "codestar-notifications": ["types-aiobotocore-codestar-notifications>=2.6.0, <2.7.0"],
        "cognito-identity": ["types-aiobotocore-cognito-identity>=2.6.0, <2.7.0"],
        "cognito-idp": ["types-aiobotocore-cognito-idp>=2.6.0, <2.7.0"],
        "cognito-sync": ["types-aiobotocore-cognito-sync>=2.6.0, <2.7.0"],
        "comprehend": ["types-aiobotocore-comprehend>=2.6.0, <2.7.0"],
        "comprehendmedical": ["types-aiobotocore-comprehendmedical>=2.6.0, <2.7.0"],
        "compute-optimizer": ["types-aiobotocore-compute-optimizer>=2.6.0, <2.7.0"],
        "config": ["types-aiobotocore-config>=2.6.0, <2.7.0"],
        "connect": ["types-aiobotocore-connect>=2.6.0, <2.7.0"],
        "connect-contact-lens": ["types-aiobotocore-connect-contact-lens>=2.6.0, <2.7.0"],
        "connectcampaigns": ["types-aiobotocore-connectcampaigns>=2.6.0, <2.7.0"],
        "connectcases": ["types-aiobotocore-connectcases>=2.6.0, <2.7.0"],
        "connectparticipant": ["types-aiobotocore-connectparticipant>=2.6.0, <2.7.0"],
        "controltower": ["types-aiobotocore-controltower>=2.6.0, <2.7.0"],
        "cur": ["types-aiobotocore-cur>=2.6.0, <2.7.0"],
        "customer-profiles": ["types-aiobotocore-customer-profiles>=2.6.0, <2.7.0"],
        "databrew": ["types-aiobotocore-databrew>=2.6.0, <2.7.0"],
        "dataexchange": ["types-aiobotocore-dataexchange>=2.6.0, <2.7.0"],
        "datapipeline": ["types-aiobotocore-datapipeline>=2.6.0, <2.7.0"],
        "datasync": ["types-aiobotocore-datasync>=2.6.0, <2.7.0"],
        "dax": ["types-aiobotocore-dax>=2.6.0, <2.7.0"],
        "detective": ["types-aiobotocore-detective>=2.6.0, <2.7.0"],
        "devicefarm": ["types-aiobotocore-devicefarm>=2.6.0, <2.7.0"],
        "devops-guru": ["types-aiobotocore-devops-guru>=2.6.0, <2.7.0"],
        "directconnect": ["types-aiobotocore-directconnect>=2.6.0, <2.7.0"],
        "discovery": ["types-aiobotocore-discovery>=2.6.0, <2.7.0"],
        "dlm": ["types-aiobotocore-dlm>=2.6.0, <2.7.0"],
        "dms": ["types-aiobotocore-dms>=2.6.0, <2.7.0"],
        "docdb": ["types-aiobotocore-docdb>=2.6.0, <2.7.0"],
        "docdb-elastic": ["types-aiobotocore-docdb-elastic>=2.6.0, <2.7.0"],
        "drs": ["types-aiobotocore-drs>=2.6.0, <2.7.0"],
        "ds": ["types-aiobotocore-ds>=2.6.0, <2.7.0"],
        "dynamodb": ["types-aiobotocore-dynamodb>=2.6.0, <2.7.0"],
        "dynamodbstreams": ["types-aiobotocore-dynamodbstreams>=2.6.0, <2.7.0"],
        "ebs": ["types-aiobotocore-ebs>=2.6.0, <2.7.0"],
        "ec2": ["types-aiobotocore-ec2>=2.6.0, <2.7.0"],
        "ec2-instance-connect": ["types-aiobotocore-ec2-instance-connect>=2.6.0, <2.7.0"],
        "ecr": ["types-aiobotocore-ecr>=2.6.0, <2.7.0"],
        "ecr-public": ["types-aiobotocore-ecr-public>=2.6.0, <2.7.0"],
        "ecs": ["types-aiobotocore-ecs>=2.6.0, <2.7.0"],
        "efs": ["types-aiobotocore-efs>=2.6.0, <2.7.0"],
        "eks": ["types-aiobotocore-eks>=2.6.0, <2.7.0"],
        "elastic-inference": ["types-aiobotocore-elastic-inference>=2.6.0, <2.7.0"],
        "elasticache": ["types-aiobotocore-elasticache>=2.6.0, <2.7.0"],
        "elasticbeanstalk": ["types-aiobotocore-elasticbeanstalk>=2.6.0, <2.7.0"],
        "elastictranscoder": ["types-aiobotocore-elastictranscoder>=2.6.0, <2.7.0"],
        "elb": ["types-aiobotocore-elb>=2.6.0, <2.7.0"],
        "elbv2": ["types-aiobotocore-elbv2>=2.6.0, <2.7.0"],
        "emr": ["types-aiobotocore-emr>=2.6.0, <2.7.0"],
        "emr-containers": ["types-aiobotocore-emr-containers>=2.6.0, <2.7.0"],
        "emr-serverless": ["types-aiobotocore-emr-serverless>=2.6.0, <2.7.0"],
        "entityresolution": ["types-aiobotocore-entityresolution>=2.6.0, <2.7.0"],
        "es": ["types-aiobotocore-es>=2.6.0, <2.7.0"],
        "events": ["types-aiobotocore-events>=2.6.0, <2.7.0"],
        "evidently": ["types-aiobotocore-evidently>=2.6.0, <2.7.0"],
        "finspace": ["types-aiobotocore-finspace>=2.6.0, <2.7.0"],
        "finspace-data": ["types-aiobotocore-finspace-data>=2.6.0, <2.7.0"],
        "firehose": ["types-aiobotocore-firehose>=2.6.0, <2.7.0"],
        "fis": ["types-aiobotocore-fis>=2.6.0, <2.7.0"],
        "fms": ["types-aiobotocore-fms>=2.6.0, <2.7.0"],
        "forecast": ["types-aiobotocore-forecast>=2.6.0, <2.7.0"],
        "forecastquery": ["types-aiobotocore-forecastquery>=2.6.0, <2.7.0"],
        "frauddetector": ["types-aiobotocore-frauddetector>=2.6.0, <2.7.0"],
        "fsx": ["types-aiobotocore-fsx>=2.6.0, <2.7.0"],
        "gamelift": ["types-aiobotocore-gamelift>=2.6.0, <2.7.0"],
        "gamesparks": ["types-aiobotocore-gamesparks>=2.6.0, <2.7.0"],
        "glacier": ["types-aiobotocore-glacier>=2.6.0, <2.7.0"],
        "globalaccelerator": ["types-aiobotocore-globalaccelerator>=2.6.0, <2.7.0"],
        "glue": ["types-aiobotocore-glue>=2.6.0, <2.7.0"],
        "grafana": ["types-aiobotocore-grafana>=2.6.0, <2.7.0"],
        "greengrass": ["types-aiobotocore-greengrass>=2.6.0, <2.7.0"],
        "greengrassv2": ["types-aiobotocore-greengrassv2>=2.6.0, <2.7.0"],
        "groundstation": ["types-aiobotocore-groundstation>=2.6.0, <2.7.0"],
        "guardduty": ["types-aiobotocore-guardduty>=2.6.0, <2.7.0"],
        "health": ["types-aiobotocore-health>=2.6.0, <2.7.0"],
        "healthlake": ["types-aiobotocore-healthlake>=2.6.0, <2.7.0"],
        "honeycode": ["types-aiobotocore-honeycode>=2.6.0, <2.7.0"],
        "iam": ["types-aiobotocore-iam>=2.6.0, <2.7.0"],
        "identitystore": ["types-aiobotocore-identitystore>=2.6.0, <2.7.0"],
        "imagebuilder": ["types-aiobotocore-imagebuilder>=2.6.0, <2.7.0"],
        "importexport": ["types-aiobotocore-importexport>=2.6.0, <2.7.0"],
        "inspector": ["types-aiobotocore-inspector>=2.6.0, <2.7.0"],
        "inspector2": ["types-aiobotocore-inspector2>=2.6.0, <2.7.0"],
        "internetmonitor": ["types-aiobotocore-internetmonitor>=2.6.0, <2.7.0"],
        "iot": ["types-aiobotocore-iot>=2.6.0, <2.7.0"],
        "iot-data": ["types-aiobotocore-iot-data>=2.6.0, <2.7.0"],
        "iot-jobs-data": ["types-aiobotocore-iot-jobs-data>=2.6.0, <2.7.0"],
        "iot-roborunner": ["types-aiobotocore-iot-roborunner>=2.6.0, <2.7.0"],
        "iot1click-devices": ["types-aiobotocore-iot1click-devices>=2.6.0, <2.7.0"],
        "iot1click-projects": ["types-aiobotocore-iot1click-projects>=2.6.0, <2.7.0"],
        "iotanalytics": ["types-aiobotocore-iotanalytics>=2.6.0, <2.7.0"],
        "iotdeviceadvisor": ["types-aiobotocore-iotdeviceadvisor>=2.6.0, <2.7.0"],
        "iotevents": ["types-aiobotocore-iotevents>=2.6.0, <2.7.0"],
        "iotevents-data": ["types-aiobotocore-iotevents-data>=2.6.0, <2.7.0"],
        "iotfleethub": ["types-aiobotocore-iotfleethub>=2.6.0, <2.7.0"],
        "iotfleetwise": ["types-aiobotocore-iotfleetwise>=2.6.0, <2.7.0"],
        "iotsecuretunneling": ["types-aiobotocore-iotsecuretunneling>=2.6.0, <2.7.0"],
        "iotsitewise": ["types-aiobotocore-iotsitewise>=2.6.0, <2.7.0"],
        "iotthingsgraph": ["types-aiobotocore-iotthingsgraph>=2.6.0, <2.7.0"],
        "iottwinmaker": ["types-aiobotocore-iottwinmaker>=2.6.0, <2.7.0"],
        "iotwireless": ["types-aiobotocore-iotwireless>=2.6.0, <2.7.0"],
        "ivs": ["types-aiobotocore-ivs>=2.6.0, <2.7.0"],
        "ivs-realtime": ["types-aiobotocore-ivs-realtime>=2.6.0, <2.7.0"],
        "ivschat": ["types-aiobotocore-ivschat>=2.6.0, <2.7.0"],
        "kafka": ["types-aiobotocore-kafka>=2.6.0, <2.7.0"],
        "kafkaconnect": ["types-aiobotocore-kafkaconnect>=2.6.0, <2.7.0"],
        "kendra": ["types-aiobotocore-kendra>=2.6.0, <2.7.0"],
        "kendra-ranking": ["types-aiobotocore-kendra-ranking>=2.6.0, <2.7.0"],
        "keyspaces": ["types-aiobotocore-keyspaces>=2.6.0, <2.7.0"],
        "kinesis": ["types-aiobotocore-kinesis>=2.6.0, <2.7.0"],
        "kinesis-video-archived-media": [
            "types-aiobotocore-kinesis-video-archived-media>=2.6.0, <2.7.0"
        ],
        "kinesis-video-media": ["types-aiobotocore-kinesis-video-media>=2.6.0, <2.7.0"],
        "kinesis-video-signaling": ["types-aiobotocore-kinesis-video-signaling>=2.6.0, <2.7.0"],
        "kinesis-video-webrtc-storage": [
            "types-aiobotocore-kinesis-video-webrtc-storage>=2.6.0, <2.7.0"
        ],
        "kinesisanalytics": ["types-aiobotocore-kinesisanalytics>=2.6.0, <2.7.0"],
        "kinesisanalyticsv2": ["types-aiobotocore-kinesisanalyticsv2>=2.6.0, <2.7.0"],
        "kinesisvideo": ["types-aiobotocore-kinesisvideo>=2.6.0, <2.7.0"],
        "kms": ["types-aiobotocore-kms>=2.6.0, <2.7.0"],
        "lakeformation": ["types-aiobotocore-lakeformation>=2.6.0, <2.7.0"],
        "lambda": ["types-aiobotocore-lambda>=2.6.0, <2.7.0"],
        "lex-models": ["types-aiobotocore-lex-models>=2.6.0, <2.7.0"],
        "lex-runtime": ["types-aiobotocore-lex-runtime>=2.6.0, <2.7.0"],
        "lexv2-models": ["types-aiobotocore-lexv2-models>=2.6.0, <2.7.0"],
        "lexv2-runtime": ["types-aiobotocore-lexv2-runtime>=2.6.0, <2.7.0"],
        "license-manager": ["types-aiobotocore-license-manager>=2.6.0, <2.7.0"],
        "license-manager-linux-subscriptions": [
            "types-aiobotocore-license-manager-linux-subscriptions>=2.6.0, <2.7.0"
        ],
        "license-manager-user-subscriptions": [
            "types-aiobotocore-license-manager-user-subscriptions>=2.6.0, <2.7.0"
        ],
        "lightsail": ["types-aiobotocore-lightsail>=2.6.0, <2.7.0"],
        "location": ["types-aiobotocore-location>=2.6.0, <2.7.0"],
        "logs": ["types-aiobotocore-logs>=2.6.0, <2.7.0"],
        "lookoutequipment": ["types-aiobotocore-lookoutequipment>=2.6.0, <2.7.0"],
        "lookoutmetrics": ["types-aiobotocore-lookoutmetrics>=2.6.0, <2.7.0"],
        "lookoutvision": ["types-aiobotocore-lookoutvision>=2.6.0, <2.7.0"],
        "m2": ["types-aiobotocore-m2>=2.6.0, <2.7.0"],
        "machinelearning": ["types-aiobotocore-machinelearning>=2.6.0, <2.7.0"],
        "macie": ["types-aiobotocore-macie>=2.6.0, <2.7.0"],
        "macie2": ["types-aiobotocore-macie2>=2.6.0, <2.7.0"],
        "managedblockchain": ["types-aiobotocore-managedblockchain>=2.6.0, <2.7.0"],
        "managedblockchain-query": ["types-aiobotocore-managedblockchain-query>=2.6.0, <2.7.0"],
        "marketplace-catalog": ["types-aiobotocore-marketplace-catalog>=2.6.0, <2.7.0"],
        "marketplace-entitlement": ["types-aiobotocore-marketplace-entitlement>=2.6.0, <2.7.0"],
        "marketplacecommerceanalytics": [
            "types-aiobotocore-marketplacecommerceanalytics>=2.6.0, <2.7.0"
        ],
        "mediaconnect": ["types-aiobotocore-mediaconnect>=2.6.0, <2.7.0"],
        "mediaconvert": ["types-aiobotocore-mediaconvert>=2.6.0, <2.7.0"],
        "medialive": ["types-aiobotocore-medialive>=2.6.0, <2.7.0"],
        "mediapackage": ["types-aiobotocore-mediapackage>=2.6.0, <2.7.0"],
        "mediapackage-vod": ["types-aiobotocore-mediapackage-vod>=2.6.0, <2.7.0"],
        "mediapackagev2": ["types-aiobotocore-mediapackagev2>=2.6.0, <2.7.0"],
        "mediastore": ["types-aiobotocore-mediastore>=2.6.0, <2.7.0"],
        "mediastore-data": ["types-aiobotocore-mediastore-data>=2.6.0, <2.7.0"],
        "mediatailor": ["types-aiobotocore-mediatailor>=2.6.0, <2.7.0"],
        "medical-imaging": ["types-aiobotocore-medical-imaging>=2.6.0, <2.7.0"],
        "memorydb": ["types-aiobotocore-memorydb>=2.6.0, <2.7.0"],
        "meteringmarketplace": ["types-aiobotocore-meteringmarketplace>=2.6.0, <2.7.0"],
        "mgh": ["types-aiobotocore-mgh>=2.6.0, <2.7.0"],
        "mgn": ["types-aiobotocore-mgn>=2.6.0, <2.7.0"],
        "migration-hub-refactor-spaces": [
            "types-aiobotocore-migration-hub-refactor-spaces>=2.6.0, <2.7.0"
        ],
        "migrationhub-config": ["types-aiobotocore-migrationhub-config>=2.6.0, <2.7.0"],
        "migrationhuborchestrator": ["types-aiobotocore-migrationhuborchestrator>=2.6.0, <2.7.0"],
        "migrationhubstrategy": ["types-aiobotocore-migrationhubstrategy>=2.6.0, <2.7.0"],
        "mobile": ["types-aiobotocore-mobile>=2.6.0, <2.7.0"],
        "mq": ["types-aiobotocore-mq>=2.6.0, <2.7.0"],
        "mturk": ["types-aiobotocore-mturk>=2.6.0, <2.7.0"],
        "mwaa": ["types-aiobotocore-mwaa>=2.6.0, <2.7.0"],
        "neptune": ["types-aiobotocore-neptune>=2.6.0, <2.7.0"],
        "network-firewall": ["types-aiobotocore-network-firewall>=2.6.0, <2.7.0"],
        "networkmanager": ["types-aiobotocore-networkmanager>=2.6.0, <2.7.0"],
        "nimble": ["types-aiobotocore-nimble>=2.6.0, <2.7.0"],
        "oam": ["types-aiobotocore-oam>=2.6.0, <2.7.0"],
        "omics": ["types-aiobotocore-omics>=2.6.0, <2.7.0"],
        "opensearch": ["types-aiobotocore-opensearch>=2.6.0, <2.7.0"],
        "opensearchserverless": ["types-aiobotocore-opensearchserverless>=2.6.0, <2.7.0"],
        "opsworks": ["types-aiobotocore-opsworks>=2.6.0, <2.7.0"],
        "opsworkscm": ["types-aiobotocore-opsworkscm>=2.6.0, <2.7.0"],
        "organizations": ["types-aiobotocore-organizations>=2.6.0, <2.7.0"],
        "osis": ["types-aiobotocore-osis>=2.6.0, <2.7.0"],
        "outposts": ["types-aiobotocore-outposts>=2.6.0, <2.7.0"],
        "panorama": ["types-aiobotocore-panorama>=2.6.0, <2.7.0"],
        "payment-cryptography": ["types-aiobotocore-payment-cryptography>=2.6.0, <2.7.0"],
        "payment-cryptography-data": ["types-aiobotocore-payment-cryptography-data>=2.6.0, <2.7.0"],
        "personalize": ["types-aiobotocore-personalize>=2.6.0, <2.7.0"],
        "personalize-events": ["types-aiobotocore-personalize-events>=2.6.0, <2.7.0"],
        "personalize-runtime": ["types-aiobotocore-personalize-runtime>=2.6.0, <2.7.0"],
        "pi": ["types-aiobotocore-pi>=2.6.0, <2.7.0"],
        "pinpoint": ["types-aiobotocore-pinpoint>=2.6.0, <2.7.0"],
        "pinpoint-email": ["types-aiobotocore-pinpoint-email>=2.6.0, <2.7.0"],
        "pinpoint-sms-voice": ["types-aiobotocore-pinpoint-sms-voice>=2.6.0, <2.7.0"],
        "pinpoint-sms-voice-v2": ["types-aiobotocore-pinpoint-sms-voice-v2>=2.6.0, <2.7.0"],
        "pipes": ["types-aiobotocore-pipes>=2.6.0, <2.7.0"],
        "polly": ["types-aiobotocore-polly>=2.6.0, <2.7.0"],
        "pricing": ["types-aiobotocore-pricing>=2.6.0, <2.7.0"],
        "privatenetworks": ["types-aiobotocore-privatenetworks>=2.6.0, <2.7.0"],
        "proton": ["types-aiobotocore-proton>=2.6.0, <2.7.0"],
        "qldb": ["types-aiobotocore-qldb>=2.6.0, <2.7.0"],
        "qldb-session": ["types-aiobotocore-qldb-session>=2.6.0, <2.7.0"],
        "quicksight": ["types-aiobotocore-quicksight>=2.6.0, <2.7.0"],
        "ram": ["types-aiobotocore-ram>=2.6.0, <2.7.0"],
        "rbin": ["types-aiobotocore-rbin>=2.6.0, <2.7.0"],
        "rds": ["types-aiobotocore-rds>=2.6.0, <2.7.0"],
        "rds-data": ["types-aiobotocore-rds-data>=2.6.0, <2.7.0"],
        "redshift": ["types-aiobotocore-redshift>=2.6.0, <2.7.0"],
        "redshift-data": ["types-aiobotocore-redshift-data>=2.6.0, <2.7.0"],
        "redshift-serverless": ["types-aiobotocore-redshift-serverless>=2.6.0, <2.7.0"],
        "rekognition": ["types-aiobotocore-rekognition>=2.6.0, <2.7.0"],
        "resiliencehub": ["types-aiobotocore-resiliencehub>=2.6.0, <2.7.0"],
        "resource-explorer-2": ["types-aiobotocore-resource-explorer-2>=2.6.0, <2.7.0"],
        "resource-groups": ["types-aiobotocore-resource-groups>=2.6.0, <2.7.0"],
        "resourcegroupstaggingapi": ["types-aiobotocore-resourcegroupstaggingapi>=2.6.0, <2.7.0"],
        "robomaker": ["types-aiobotocore-robomaker>=2.6.0, <2.7.0"],
        "rolesanywhere": ["types-aiobotocore-rolesanywhere>=2.6.0, <2.7.0"],
        "route53": ["types-aiobotocore-route53>=2.6.0, <2.7.0"],
        "route53-recovery-cluster": ["types-aiobotocore-route53-recovery-cluster>=2.6.0, <2.7.0"],
        "route53-recovery-control-config": [
            "types-aiobotocore-route53-recovery-control-config>=2.6.0, <2.7.0"
        ],
        "route53-recovery-readiness": [
            "types-aiobotocore-route53-recovery-readiness>=2.6.0, <2.7.0"
        ],
        "route53domains": ["types-aiobotocore-route53domains>=2.6.0, <2.7.0"],
        "route53resolver": ["types-aiobotocore-route53resolver>=2.6.0, <2.7.0"],
        "rum": ["types-aiobotocore-rum>=2.6.0, <2.7.0"],
        "s3": ["types-aiobotocore-s3>=2.6.0, <2.7.0"],
        "s3control": ["types-aiobotocore-s3control>=2.6.0, <2.7.0"],
        "s3outposts": ["types-aiobotocore-s3outposts>=2.6.0, <2.7.0"],
        "sagemaker": ["types-aiobotocore-sagemaker>=2.6.0, <2.7.0"],
        "sagemaker-a2i-runtime": ["types-aiobotocore-sagemaker-a2i-runtime>=2.6.0, <2.7.0"],
        "sagemaker-edge": ["types-aiobotocore-sagemaker-edge>=2.6.0, <2.7.0"],
        "sagemaker-featurestore-runtime": [
            "types-aiobotocore-sagemaker-featurestore-runtime>=2.6.0, <2.7.0"
        ],
        "sagemaker-geospatial": ["types-aiobotocore-sagemaker-geospatial>=2.6.0, <2.7.0"],
        "sagemaker-metrics": ["types-aiobotocore-sagemaker-metrics>=2.6.0, <2.7.0"],
        "sagemaker-runtime": ["types-aiobotocore-sagemaker-runtime>=2.6.0, <2.7.0"],
        "savingsplans": ["types-aiobotocore-savingsplans>=2.6.0, <2.7.0"],
        "scheduler": ["types-aiobotocore-scheduler>=2.6.0, <2.7.0"],
        "schemas": ["types-aiobotocore-schemas>=2.6.0, <2.7.0"],
        "sdb": ["types-aiobotocore-sdb>=2.6.0, <2.7.0"],
        "secretsmanager": ["types-aiobotocore-secretsmanager>=2.6.0, <2.7.0"],
        "securityhub": ["types-aiobotocore-securityhub>=2.6.0, <2.7.0"],
        "securitylake": ["types-aiobotocore-securitylake>=2.6.0, <2.7.0"],
        "serverlessrepo": ["types-aiobotocore-serverlessrepo>=2.6.0, <2.7.0"],
        "service-quotas": ["types-aiobotocore-service-quotas>=2.6.0, <2.7.0"],
        "servicecatalog": ["types-aiobotocore-servicecatalog>=2.6.0, <2.7.0"],
        "servicecatalog-appregistry": [
            "types-aiobotocore-servicecatalog-appregistry>=2.6.0, <2.7.0"
        ],
        "servicediscovery": ["types-aiobotocore-servicediscovery>=2.6.0, <2.7.0"],
        "ses": ["types-aiobotocore-ses>=2.6.0, <2.7.0"],
        "sesv2": ["types-aiobotocore-sesv2>=2.6.0, <2.7.0"],
        "shield": ["types-aiobotocore-shield>=2.6.0, <2.7.0"],
        "signer": ["types-aiobotocore-signer>=2.6.0, <2.7.0"],
        "simspaceweaver": ["types-aiobotocore-simspaceweaver>=2.6.0, <2.7.0"],
        "sms": ["types-aiobotocore-sms>=2.6.0, <2.7.0"],
        "sms-voice": ["types-aiobotocore-sms-voice>=2.6.0, <2.7.0"],
        "snow-device-management": ["types-aiobotocore-snow-device-management>=2.6.0, <2.7.0"],
        "snowball": ["types-aiobotocore-snowball>=2.6.0, <2.7.0"],
        "sns": ["types-aiobotocore-sns>=2.6.0, <2.7.0"],
        "sqs": ["types-aiobotocore-sqs>=2.6.0, <2.7.0"],
        "ssm": ["types-aiobotocore-ssm>=2.6.0, <2.7.0"],
        "ssm-contacts": ["types-aiobotocore-ssm-contacts>=2.6.0, <2.7.0"],
        "ssm-incidents": ["types-aiobotocore-ssm-incidents>=2.6.0, <2.7.0"],
        "ssm-sap": ["types-aiobotocore-ssm-sap>=2.6.0, <2.7.0"],
        "sso": ["types-aiobotocore-sso>=2.6.0, <2.7.0"],
        "sso-admin": ["types-aiobotocore-sso-admin>=2.6.0, <2.7.0"],
        "sso-oidc": ["types-aiobotocore-sso-oidc>=2.6.0, <2.7.0"],
        "stepfunctions": ["types-aiobotocore-stepfunctions>=2.6.0, <2.7.0"],
        "storagegateway": ["types-aiobotocore-storagegateway>=2.6.0, <2.7.0"],
        "sts": ["types-aiobotocore-sts>=2.6.0, <2.7.0"],
        "support": ["types-aiobotocore-support>=2.6.0, <2.7.0"],
        "support-app": ["types-aiobotocore-support-app>=2.6.0, <2.7.0"],
        "swf": ["types-aiobotocore-swf>=2.6.0, <2.7.0"],
        "synthetics": ["types-aiobotocore-synthetics>=2.6.0, <2.7.0"],
        "textract": ["types-aiobotocore-textract>=2.6.0, <2.7.0"],
        "timestream-query": ["types-aiobotocore-timestream-query>=2.6.0, <2.7.0"],
        "timestream-write": ["types-aiobotocore-timestream-write>=2.6.0, <2.7.0"],
        "tnb": ["types-aiobotocore-tnb>=2.6.0, <2.7.0"],
        "transcribe": ["types-aiobotocore-transcribe>=2.6.0, <2.7.0"],
        "transfer": ["types-aiobotocore-transfer>=2.6.0, <2.7.0"],
        "translate": ["types-aiobotocore-translate>=2.6.0, <2.7.0"],
        "verifiedpermissions": ["types-aiobotocore-verifiedpermissions>=2.6.0, <2.7.0"],
        "voice-id": ["types-aiobotocore-voice-id>=2.6.0, <2.7.0"],
        "vpc-lattice": ["types-aiobotocore-vpc-lattice>=2.6.0, <2.7.0"],
        "waf": ["types-aiobotocore-waf>=2.6.0, <2.7.0"],
        "waf-regional": ["types-aiobotocore-waf-regional>=2.6.0, <2.7.0"],
        "wafv2": ["types-aiobotocore-wafv2>=2.6.0, <2.7.0"],
        "wellarchitected": ["types-aiobotocore-wellarchitected>=2.6.0, <2.7.0"],
        "wisdom": ["types-aiobotocore-wisdom>=2.6.0, <2.7.0"],
        "workdocs": ["types-aiobotocore-workdocs>=2.6.0, <2.7.0"],
        "worklink": ["types-aiobotocore-worklink>=2.6.0, <2.7.0"],
        "workmail": ["types-aiobotocore-workmail>=2.6.0, <2.7.0"],
        "workmailmessageflow": ["types-aiobotocore-workmailmessageflow>=2.6.0, <2.7.0"],
        "workspaces": ["types-aiobotocore-workspaces>=2.6.0, <2.7.0"],
        "workspaces-web": ["types-aiobotocore-workspaces-web>=2.6.0, <2.7.0"],
        "xray": ["types-aiobotocore-xray>=2.6.0, <2.7.0"],
    },
    zip_safe=False,
)
